<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=uk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'activer_plugin' => 'Активувати плагін',
	'affichage' => 'Показати',
	'aide_non_disponible' => 'Цей розділ он-лайн допомоги ще не перекладено українською.',
	'annuler_recherche' => 'Відмінити пошук',
	'auteur' => 'Автор:',
	'avis_acces_interdit' => 'Доступ заборонено.',
	'avis_acces_interdit_prive' => 'У вас немає прав для перегляду сторінки <b>@exec@</b>.',
	'avis_article_modifie' => 'Увага: @nom_auteur_modif@ вносив зміни в цю статтю @date_diff@ хвилин тому',
	'avis_aucun_resultat' => 'Нічого не знайдено',
	'avis_base_inaccessible' => 'Неможливо підключитися до бази @base@.',
	'avis_chemin_invalide_1' => 'Шлях, що ви вибрали',
	'avis_chemin_invalide_2' => 'схоже, що не вірно. Будь ласка, поверніться на попередню сторінку і перевірте надану інформацію.',
	'avis_connexion_echec_1' => 'Не вдалося підключится до SQL серверу.',
	'avis_connexion_echec_2' => 'Будь ласка, поверніться на попередню сторінку і перевірте внесену інформацію.',
	'avis_connexion_echec_3' => '<b>N.B.</b> На багатьох серверах ви повинні зробити запит для включення вашого доступу до бази даних SQL перед тим, як використовувати її. Якщо ви не можете встановити з’єднання, упевніться, що цей запит дійсно було зроблено.',
	'avis_connexion_erreur_creer_base' => 'База даних не може бути створена.',
	'avis_connexion_erreur_nom_base' => 'Назва бази може складатися тільки з латинських букв, цифр і знаків нижнього підкреслювання.',
	'avis_connexion_ldap_echec_1' => 'Не вдалося подключитися до LDAP.',
	'avis_connexion_ldap_echec_2' => 'Поверніться на попередню сторінку і перевірте внесену вами інформацію.',
	'avis_connexion_ldap_echec_3' => 'Крім того, не використовуйте підтримку LDAP для імпорту користувачів.',
	'avis_deplacement_rubrique' => 'Увага! В цій рубриці знаходиться @contient_breves@ новин@scb@: якщо ви переміщуєте її, будь ласка, поставьте відмітку для підтвердження операції.',
	'avis_erreur_connexion_mysql' => 'Помилка з’єднання з SQL ',
	'avis_espace_interdit' => '<b>Заборонений простір</b> <div>SPIP вже встановлено.</div> ',
	'avis_lecture_noms_bases_1' => 'Програма установки не змогла прочитати імена встановлених баз даних .',
	'avis_lecture_noms_bases_2' => 'Жодна з баз даних не є доступною або функцію, що дозволяє вносити до списку бази даних, було вимкнено з метою безпеки (забагато послуг хостингу).',
	'avis_lecture_noms_bases_3' => 'В другому випадку можливо, що база даних, названа за вашим логіном, может бути використана:',
	'avis_non_acces_page' => 'У вас нема доступу до цієї сторінки.',
	'avis_operation_echec' => 'Не вдалося виконати операцію.',
	'avis_operation_impossible' => 'Неможливо виконати операцію',
	'avis_suppression_base' => 'Увага: видалення даних неможливо відмінити',

	// B
	'bouton_acces_ldap' => 'Додати доступ до LDAP',
	'bouton_ajouter' => 'Додати',
	'bouton_annuler' => 'Відмінити',
	'bouton_cache_activer' => 'Увімкнути кешування',
	'bouton_cache_desactiver' => 'Виключити кешування',
	'bouton_demande_publication' => 'Запитати публікацію цієї статті',
	'bouton_desactive_tout' => 'Усе відключити',
	'bouton_desinstaller' => 'Видалити',
	'bouton_effacer_tout' => 'Видалити УСЕ',
	'bouton_envoyer_message' => 'Заключне повідомлення: Надіслати',
	'bouton_fermer' => 'Закрити',
	'bouton_mettre_a_jour_base' => 'Оновити базу даних',
	'bouton_modifier' => 'Змінити',
	'bouton_radio_afficher' => 'Показати',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Показувати у переліку авторів, що знаходяться на сайті',
	'bouton_radio_envoi_annonces_adresse' => 'Відправити оголошення на адресу:',
	'bouton_radio_envoi_liste_nouveautes' => 'Відправити список останніх новин',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Не показувати у переліку авторів, що знаходяться на сайті',
	'bouton_radio_non_envoi_annonces_editoriales' => 'Не відправляти ніяких редакційних оголошень',
	'bouton_redirection' => 'ПЕРЕНАПРАВЛЕННЯ',
	'bouton_reinitialiser_aux_valeurs_par_defaut' => 'Відновити початкові значення',
	'bouton_relancer_inscription' => 'Перезапустити реєстрацію',
	'bouton_relancer_inscriptions' => 'Перезапустити реєстрації',
	'bouton_relancer_installation' => 'Перезапустити установку',
	'bouton_reset_password' => 'Створити новий пароль і відправити по e-mail',
	'bouton_suivant' => 'Наступний',
	'bouton_tenter_recuperation' => 'Спробуємо відремонтувати базу',
	'bouton_test_proxy' => 'Перевірити проксі',
	'bouton_vider_cache' => 'Очистити кеш',

	// C
	'cache_modifiable_webmestre' => 'Цей параметр може бути змінений тільки вебмастером.',
	'calendrier_synchro' => 'Якщо ви використовуєте календар, сумісний з <b>iCal</b>, ви можете узгодити його з даними сайту.',
	'config_activer_champs' => 'Увімкнути наступні поля',
	'config_choix_base_sup' => 'Виберіть базу на цьому сервері',
	'config_erreur_base_sup' => 'SPIP не може відобразити список доступних баз даних',
	'config_info_base_sup' => 'Якщо вам потрібний запит інших баз даних, використовуючи SPIP, незалежно від того, чи знаходяться вони на тому ж SQL сервері або де-інде, використовуйте форму, що показана нижче для їх опису. Якщо ви залишите деякі поля пустими, то пов’язані деталі будуть використовуватися з основною базой даних.',
	'config_info_base_sup_disponibles' => 'Додаткові бази даних, до яких можна відправити запити:',
	'config_info_enregistree' => 'Нові налаштування збережено',
	'config_info_logos' => 'Кожному елементу сайту можна встановити свій логотип і також логотип для відображення «при наведенні миші»',
	'config_info_logos_utiliser' => 'Використовувати логотипи',
	'config_info_logos_utiliser_non' => 'Не використовувати логотипи',
	'config_info_logos_utiliser_survol' => 'Дозволити додавати логотип для відображення «при наведенні миші»',
	'config_info_logos_utiliser_survol_non' => 'Заборонити додавати логотип для відображення «при наведенні миші»',
	'config_info_redirection' => 'Віртуальна стаття - це можливість перенаправляти відвідувачів по довільному URL, як на іншу сторінку цього сайта, так і на будь-яке посилання в інтернеті.',
	'config_redirection' => 'Віртуальні статті (редирект)',
	'config_titre_base_sup' => 'Опис додаткової бази даних',
	'config_titre_base_sup_choix' => 'Виберіть додаткову базу даних',
	'connexion_ldap' => 'З’єднання:',
	'creer_et_associer_un_auteur' => 'Створити і додати автора',

	// D
	'date_mot_heures' => ':',

	// E
	'ecran_connexion_couleur_principale' => 'Головний колір',
	'ecran_connexion_image_fond' => 'Зображення на тло',
	'ecran_connexion_image_fond_explication' => 'Використати зображення (JPEG, 1920x1080 пікселів)',
	'ecran_connexion_image_revenir_couleur_defaut' => 'Повернути кольори за замовчуванням',
	'ecran_connexion_titre' => 'Сторінка входу',
	'ecran_securite' => ' + сервіс безпеки @version@',
	'email' => 'email',
	'email_2' => 'email:',
	'en_savoir_plus' => 'Детальніше',
	'entree_adresse_annuaire' => 'Довідник адрес',
	'entree_adresse_email' => 'Ваша адреса електронної пошти',
	'entree_adresse_email_2' => 'E-mail',
	'entree_base_donnee_1' => 'Адреса серверу бази даних',
	'entree_base_donnee_2' => '(Зазвичай це «localhost», але ви можете уточнити в налаштуваннях хостінгу)',
	'entree_biographie' => 'Коротка біографія на декілька слів.',
	'entree_chemin_acces' => 'Ввести шлях доступу:',
	'entree_cle_pgp' => 'Ваш ключ  PGP',
	'entree_cle_pgp_2' => 'Ключ PGP ',
	'entree_contenu_rubrique' => '(Короткий зміст рубрики.)',
	'entree_identifiants_connexion' => 'Логін і пароль',
	'entree_identifiants_connexion_2' => 'Інформація про підключення',
	'entree_informations_connexion_ldap' => 'Будь ласка, вкажіть параметри підключення до LDAP. Ви можете отримати цю інформацію у вашого системного адміністратора.',
	'entree_infos_perso' => 'Хто ви?',
	'entree_infos_perso_2' => 'Хто автор?',
	'entree_interieur_rubrique' => 'В розділі:',
	'entree_liens_sites' => '<b>Гіперпосилання</b> (посилання, сайт для відвідування...)',
	'entree_login' => 'Ваш логін',
	'entree_login_connexion_1' => 'Логін з’єднання',
	'entree_login_connexion_2' => '(Іноді відповідає вашому логіну FTP доступу, а іноді залишається порожнім)',
	'entree_mot_passe' => 'Ваш пароль',
	'entree_mot_passe_1' => 'Пароль',
	'entree_mot_passe_2' => '(Іноді відповідає вашому паролю FTP доступу, а іноді залишається порожнім)',
	'entree_nom_fichier' => 'Будь ласка, виберіть файл з резервною копією @texte_compresse@:',
	'entree_nom_pseudo' => 'Ваше ім’я або псевдонім',
	'entree_nom_pseudo_1' => '(Ваше ім’я або псевдонім)',
	'entree_nom_pseudo_2' => 'Ім’я або псевдонім',
	'entree_nom_site' => 'Назва вашого сайту',
	'entree_nom_site_2' => 'Назва сайту',
	'entree_nouveau_passe' => 'Новий пароль',
	'entree_passe_ldap' => 'Пароль',
	'entree_port_annuaire' => 'Номер порту каталогу',
	'entree_signature' => 'Підпис',
	'entree_titre_obligatoire' => '<b>Заголовок</b> [обов’язково]<br />',
	'entree_url' => 'Адреса (URL) вашого сайту',
	'entree_url_2' => 'URL',
	'erreur_connect_deja_existant' => 'Сервер з такою назвою вже існує',
	'erreur_contenu_suspect' => 'Текст екрановано',
	'erreur_email_deja_existant' => 'Ця адреса електронної пошти вже зареєстрована.',
	'erreur_nom_connect_incorrect' => 'Неприпустиме ім’я серверу',
	'erreur_plugin_attribut_balise_manquant' => 'Атрибут @attribut@ відсутній в тезі @balise@.',
	'erreur_plugin_desinstalation_echouee' => 'Не вдалося видалити плагін, але ви можете відключити його.',
	'erreur_plugin_fichier_absent' => 'Відсутній файл',
	'erreur_plugin_fichier_def_absent' => 'Файл визначення  відсутній',
	'erreur_plugin_nom_fonction_interdit' => 'Ім´я функції заборонено',
	'erreur_plugin_nom_manquant' => 'Відсутня назва плагіну ',
	'erreur_plugin_prefix_manquant' => 'Простір імен плагіна невизначений',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; відсутнє в файлі опису',
	'erreur_plugin_version_manquant' => 'Відсутня версія плагіну',
	'erreur_type_fichier' => 'Неконкретний тип файлу',

	// H
	'htaccess_a_simuler' => 'Увага: в налаштуваннях веб-серверу відключено використання @htaccess@ файлів. Для забезпечення достатнього рівня безпеки внесіть зміни до налаштувань серверу самостійно або зверніться до технічної підтримки хостінгу. Ви також можете задати константи @constantes@ (в файлі mes_options.php) так, щоб ці Файли знаходились поза папкою @document_root@.',
	'htaccess_inoperant' => 'htaccess не робочий',

	// I
	'ical_info1' => 'Ця сторінка надає вам декілька методів для підтримки зв’язку з діяльністю цього сайту',
	'ical_info2' => 'Ви можете дізнатися більше в <a href="@spipnet@">документації про SPIP</a>.',
	'ical_info_calendrier' => 'В вашему розпорядженні є два календарі. Перший - це карта сайту, що відображає всі опубліковані статті. Другий містить редакторські оголошення, а також ваші останні особисті повідомлення: його збережено для вас завдяки ключу, який ви можете змінити будь-коли, підтвердивши свій пароль.',
	'ical_methode_http' => 'Завантаження',
	'ical_methode_webcal' => 'Синхронізація (webcal://)',
	'ical_texte_js' => 'Ви можете вставити цей javascript код на будь-який сайт, щоб відображати останні опубліковані статті і матеріали вашого сайту.',
	'ical_texte_prive' => 'Цей календар є строго особистим, він інформує вас про роботу зі статтями на цьому сайті (завдання, персональні налаштування, відправлені статті і новини дня...).',
	'ical_texte_public' => 'Цей календар дозволяє вам слідкувати за основною діяльністю цього сайту (публікація статтей і новин).',
	'ical_texte_rss' => 'Ви можете експортувати останні поновлення на вашому сайті в форматі XML/RSS (Rich Site Summary). Також, завдяки цьому формату даних, ви можете імпортувати інформацію з інших сайтів в ІнтерНемаі.',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Список адресатів',
	'ical_titre_rss' => 'Отримання статей і новин з інших сайтов по RSS',
	'icone_accueil' => 'Головна',
	'icone_activer_cookie' => 'Помістити cookie',
	'icone_activite' => 'Зворотній зв’язок',
	'icone_admin_plugin' => 'Плагіни',
	'icone_administration' => 'Обслуговування',
	'icone_afficher_auteurs' => 'Показати авторів',
	'icone_afficher_visiteurs' => 'Показати відвідувачів',
	'icone_arret_discussion' => 'Припинити участь в цьому обговоренні',
	'icone_calendrier' => 'Календар',
	'icone_configuration' => 'Конфігурація',
	'icone_creer_auteur' => 'Створити автора і додати до статті',
	'icone_creer_mot_cle' => 'Створити нове ключове слово і пов’язати його із цією статтею.',
	'icone_creer_rubrique_2' => 'Створити нову рубрику',
	'icone_developpement' => 'У розвитку',
	'icone_edition' => 'Редагувати',
	'icone_ma_langue' => 'Моя мова',
	'icone_mes_infos' => 'Моя інформація',
	'icone_mes_preferences' => 'Мої уподобання',
	'icone_modifier_article' => 'Змінити статтю',
	'icone_modifier_rubrique' => 'Змінити розділ',
	'icone_publication' => 'Публікації',
	'icone_relancer_signataire' => 'Відновити підпис',
	'icone_retour' => 'Назад',
	'icone_retour_article' => 'Назад до статті',
	'icone_squelette' => 'Шаблони',
	'icone_suivi_publication' => 'Моніторинг публікації',
	'icone_supprimer_cookie' => 'Видалити cookie',
	'icone_supprimer_rubrique' => 'Видалити розділ',
	'icone_supprimer_signature' => 'Видалити підпис',
	'icone_valider_signature' => 'Затвердити підпис',
	'image_administrer_rubrique' => 'Ви можете керувати цим розділом',
	'impossible_modifier_login_auteur' => 'Неможливо змінити логін.',
	'impossible_modifier_pass_auteur' => 'Неможливо змінити пароль.',
	'info_1_article' => '1 стаття',
	'info_1_auteur' => '1 автор',
	'info_1_message' => '1 повідомлення',
	'info_1_mot_cle' => '1 ключове слово',
	'info_1_rubrique' => '1 розділ',
	'info_1_visiteur' => '1 відвідувач',
	'info_activer_cookie' => 'Ви можете увімкнути <b>адміністративні cookie</b>, що дозволить вам легко перемикатися  між основною і адміністративною частиною сайту.',
	'info_activer_menu_developpement' => 'Показати меню розвитку',
	'info_admin_etre_webmestre' => 'Надати мені права вебмастера',
	'info_admin_je_suis_webmestre' => 'Я <b>вебмастер</b>',
	'info_admin_statuer_webmestre' => 'Надати цьому адміністратору права веб-майстра',
	'info_admin_webmestre' => 'Адміністратор є <b>вебмастером</b>',
	'info_administrateur' => 'Адміністратор',
	'info_administrateur_1' => 'Адміністратор',
	'info_administrateur_2' => 'на цьому сайті (<i>використовувати з пересторогою</i>)',
	'info_administrateur_site_01' => 'Якщо ви адміністратор сайта, будь ласка',
	'info_administrateur_site_02' => 'натисніть тут',
	'info_administrateurs' => 'Адміністратори',
	'info_administrer_rubrique' => 'Ви можете управляти цією рубрикою',
	'info_adresse' => 'за адресою:',
	'info_adresse_desinscription' => 'Адреса щоб відписатися:',
	'info_adresse_url' => 'Адреса (URL) загального сайту',
	'info_afficher_par_nb' => 'Показати',
	'info_aide_en_ligne' => 'SPIP Oнлайн Допомога',
	'info_ajout_image' => 'Коли ви додаєте зображення як прикріплені документи до статті, SPIP може автоматично створити зменшену копію цих зображень. Це дозволить, наприклад, автоматично створювати галерею чи портфоліо.',
	'info_ajouter_rubrique' => 'Додати іншу рубрику для управління:',
	'info_annonce_nouveautes' => 'Анонси останніх новин',
	'info_article' => 'стаття',
	'info_article_2' => 'статті',
	'info_article_a_paraitre' => 'статті, які будуть опубліковані в майбутньому',
	'info_articles_02' => 'статті',
	'info_articles_2' => 'Статті',
	'info_articles_auteur' => 'Статті автора',
	'info_articles_miens' => 'Мої статті',
	'info_articles_tous' => 'Усі статті',
	'info_articles_trouves' => 'Знайдені статті',
	'info_attente_validation' => 'Ваші статті на затвердженні',
	'info_aucun_article' => 'Нема статтей',
	'info_aucun_auteur' => 'Нема авторів',
	'info_aucun_message' => 'Нема повідомлень',
	'info_aucun_rubrique' => 'Нема розділів',
	'info_aujourdhui' => 'сьогодні:',
	'info_auteur_gere_rubriques' => 'Автор керує наступними розділами:',
	'info_auteur_gere_toutes_rubriques' => 'Автор керує <b>всіма рубриками</b>',
	'info_auteur_gere_toutes_rubriques_2' => 'Я керую <b>всіма розділами</b>',
	'info_auteurs' => 'Автори',
	'info_auteurs_par_tri' => 'Автори@partri@',
	'info_auteurs_trouves' => 'Знайдені автори',
	'info_authentification_externe' => 'Зовнішня аутентифікація',
	'info_avertissement' => 'Попередження',
	'info_barre_outils' => 'з панеллю інструментів?',
	'info_base_installee' => 'Структуру вашої бази даних встановлено.',
	'info_bio' => 'Біографія',
	'info_cache_desactive' => 'Кешування вимкнено.',
	'info_chapeau' => 'Вступ',
	'info_chapeau_2' => 'Вступ:',
	'info_chemin_acces_1' => 'Опції: <b>Шлях доступу до каталогу</b>',
	'info_chemin_acces_2' => 'Тепер ви повинні налаштувати шлях доступу до інформації в  довіднику. Ця інформація необхідна для перегляду профілів користувачів, записаних в  довіднику.',
	'info_chemin_acces_annuaire' => 'Опції: <b>Шлях доступу к каталогу</b>',
	'info_choix_base' => 'Третій етап:',
	'info_classement_1' => ' з @liste@',
	'info_classement_2' => ' з @liste@',
	'info_code_acces' => 'Не забудьте ваші власні коди доступу!',
	'info_config_suivi' => 'Якщо ця адреса відповідає списку адресатів, ви можете вказати нижче адресу, за якою учасники сайту можуть зареєструватися. Цією адресою може бути адреса сайту (наприклад сторінка списка реєстрації через мережу) або адреса електронної пошти з певною темою (наприклад: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Ви можете підписатися на почтову розсилку цього сайту і отримувати на email інформацію про статті та новини, відправлені для публікації.',
	'info_confirmer_passe' => 'Підтвердіть новий пароль:',
	'info_conflit_edition_avis_non_sauvegarde' => 'Увага! Наступні поля були змінені. Ваші внесені зміни в цих полях не були враховані.',
	'info_conflit_edition_differences' => 'Відмінності:',
	'info_conflit_edition_version_enregistree' => 'Зареєстрована версія:',
	'info_conflit_edition_votre_version' => 'Ваша версія:',
	'info_connexion_base' => 'Спроба з’єднання з базою даних',
	'info_connexion_base_donnee' => 'Підключення до бази даних',
	'info_connexion_ldap_ok' => '<b>З’єднання з LDAP встановлено. </b> <p>Ви можете перейти до наступного кроку.</p>',
	'info_connexion_mysql' => 'Ваше з’єднання з SQL',
	'info_connexion_ok' => 'З’єднання встановлено.',
	'info_contact' => 'Контакт',
	'info_contenu_articles' => 'Зміст статтей',
	'info_contributions' => 'Внески',
	'info_creation_paragraphe' => '(Розділяйте абзаци порожніми строками)',
	'info_creation_rubrique' => 'Перед тим, як писати статті, необхідно створити хоча б одну рубрику. ',
	'info_creation_tables' => 'Створення таблиць бази даних',
	'info_creer_base' => '<b>Створити</b> нову базу даних:',
	'info_dans_rubrique' => 'У рубриці :',
	'info_date_publication_anterieure' => 'Дата попередньої редакції :',
	'info_date_referencement' => 'ДАТА ПОСИЛАННЯ НА ЦЕЙ САЙТ:',
	'info_derniere_etape' => 'Готово!',
	'info_descriptif' => 'Опис:',
	'info_desinstaller_plugin' => 'видаляє дані і відключає плагін',
	'info_discussion_cours' => 'Поточні обговорення',
	'info_ecrire_article' => 'Перед тим, як писати статті, необхідно створити хоча б одну рубрику.',
	'info_email_envoi' => ' Адреса електронної пошти (необов’язково)',
	'info_email_envoi_txt' => 'Введіть e-mail адресу відправника, що використовується для відправлення електронних листів (зазвичай адреса користувача використовується як адреса відправника):',
	'info_email_webmestre' => 'E-mail веб-мастера',
	'info_envoi_email_automatique' => 'Автоматична відправка повідомлення електронної пошти ',
	'info_envoyer_maintenant' => 'Відправити зараз',
	'info_etape_suivante' => 'Перейти до наступного етапу',
	'info_etape_suivante_1' => 'Ви можете перейти до наступного етапу.',
	'info_etape_suivante_2' => 'Ви можете перейти до наступного етапу.',
	'info_exceptions_proxy' => 'Винятки для проксі',
	'info_exportation_base' => 'експортувати базу даних в @archive@',
	'info_facilite_suivi_activite' => 'Для полегшення моніторингу діяльності   редакційних SPIP сайт може відправити його поштою, наприклад, на  список розсилки редакторів, бізнес-додатки публікації та перевірки статей.', # MODIF
	'info_fichiers_authent' => 'Файл аутентифікації «.htpasswd»',
	'info_forums_abo_invites' => 'Ваш сайт має форуми за підпискою; відвідувачі можуть зареєструватися на них на основному сайті.',
	'info_gauche_admin_tech' => '<b>Сторінка тільки для вебмастера сайта.</b> <p>Ви можете виконувати завдання щодо експлуатації сайту. Частина з них може потребувати FTP-доступу до сайту.</p>',
	'info_gauche_admin_vider' => '<b>Тільки вебмастери мають доступ до цієї сторінки.</b> <p>Тут є можливість виконувати різні завдання по обслуговуванню сайта. Для виконання окремих завдань необхідний доступ до сайту по FTP.</p>',
	'info_gauche_auteurs' => 'Перелік всіх авторів сайту. Статус автора позначений кольором (адміністратор = зелений; автор = жовтий).',
	'info_gauche_auteurs_exterieurs' => 'Користувачі, що зареєструвалися, позначені синім кольором, а видалені користувачі - іконкою кошика.',
	'info_gauche_messagerie' => 'Передача повідомлень дозволяє обмінюватися повідомленнями між редакторами, зберигати нотатки (для вашого особистого використання) або показувати оголошення на основній сторінці адміністративної частини (якщо ви - адміністратор).',
	'info_gauche_statistiques_referers' => 'Ця сторінка показує список <i>посилань</i>, тобто ті сайти, які мають посилання на ваш сайт, тільки для вчора і сьогодні: фактично цей список поновлюється кожні 24 години.',
	'info_gauche_visiteurs_enregistres' => 'Ви знайдете тут зареєстрованних відвідувачів основноі частини сайту (форуми за підпискою).',
	'info_generation_miniatures_images' => 'Створення зменшених зображень',
	'info_gerer_trad_objets' => '@objets@ : управління перекладами',
	'info_hebergeur_desactiver_envoi_email' => 'Деякі хости відключають  автоматизовану відправку листів на своих серверах. В цьому випадку наступні можливості SPIP не можуть бути здійснені.',
	'info_hier' => 'вчора:',
	'info_identification_publique' => 'Ваша публична ідентифікація...',
	'info_image_process' => 'Виберіть кращий метод для створення зменшеної копії, натиснувши на відповідну картинку.',
	'info_image_process2' => 'Якщо картинки не відображаються, це значить, що ваш хостінг не підтримує розширения по роботі з зображеннями. Уточніть в технічній підтримці хостінгу про можливості використовувати бібліотеки «GD» або «Imagemagic».',
	'info_images_auto' => 'Кеш файлів зображень',
	'info_informations_personnelles' => 'Налаштування профиля',
	'info_inscription' => 'Реєстрація',
	'info_inscription_automatique' => 'Автоматична реєстрація нових авторів',
	'info_jeu_caractere' => 'Кодування сайту',
	'info_jours' => 'дні',
	'info_laisser_champs_vides' => 'залиште ці поля порожніми)',
	'info_langues' => 'Мови сайту',
	'info_ldap_ok' => 'Встанослення справжності LDAP.',
	'info_lien_hypertexte' => 'Гиперпосилання:',
	'info_liste_nouveautes_envoyee' => 'Інформацію про останні оновлення відправлено',
	'info_liste_redacteurs_connectes' => 'Автори онлайн',
	'info_login_existant' => 'Цей логін вже використовується.',
	'info_login_trop_court' => 'Занадто короткий логін.',
	'info_login_trop_court_car_pluriel' => 'Логін повинен складатися мінімум з @nb@ символів.',
	'info_logos' => 'Логотипи',
	'info_maximum' => 'максимум:',
	'info_meme_rubrique' => 'В розділі:',
	'info_message_en_redaction' => 'Ваше повідомлення в роботі',
	'info_message_technique' => 'Технічене повідомлення:',
	'info_messagerie_interne' => 'Внутрішня передача повідомлень',
	'info_mise_a_niveau_base' => 'оновлення бази даних SQL',
	'info_mise_a_niveau_base_2' => '{{Попередження!}} Ви встановили версію SPIP файлів {старіше} ніж та, яку було попередньо встановлено на цьому сайті: ви ризикуєте втратити базу даних, і тоді ваш сайт не зможе працювати належним чином. <br /> {{Перевстановіть SPIP файли.}}',
	'info_modification_enregistree' => 'Ваши зміни збережено',
	'info_modifier_auteur' => 'Змінити автора:',
	'info_modifier_rubrique' => 'Змінити розділ:',
	'info_modifier_titre' => 'Змінити: @titre@',
	'info_mon_site_spip' => 'Мій сайт ',
	'info_moyenne' => 'в средньому:',
	'info_multi_cet_article' => 'Мова статті:',
	'info_multi_langues_choisies' => 'Виберіть мови для редагування матеріалів на сайті. Мови, які вже використовує ваш сайт (наверху списку) не можуть бути вимкнені.',
	'info_multi_objets' => '@objets@ : увімкнути мовне меню',
	'info_multi_secteurs' => '... тільки для розділів в корені сайту?',
	'info_nb_articles' => '@nb@ статтей',
	'info_nb_auteurs' => '@nb@ авторів',
	'info_nb_messages' => '@nb@ повідомлень',
	'info_nb_mots_cles' => '@nb@ ключових слів',
	'info_nb_rubriques' => '@nb@ розділ(ів)',
	'info_nb_visiteurs' => '@nb@ відвідувачів',
	'info_nom' => 'Ім’я',
	'info_nom_destinataire' => 'Ім’я користувача',
	'info_nom_pas_conforme' => 'HTML теги не допускаються',
	'info_nom_site' => 'Назва вашого сайта',
	'info_nombre_articles' => '@nb_articles@ статті,',
	'info_nombre_rubriques' => '@nb_rubriques@ рубрики,',
	'info_nombre_sites' => '@nb_sites@ сайти,',
	'info_non_deplacer' => 'Не переміщувати...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP может регулярно відправляти новини, оголошення сайта
  (недавно опубліковані статті і новини).',
	'info_non_envoi_liste_nouveautes' => 'Не відправляти список останніх новин',
	'info_non_modifiable' => 'не может бути змінено',
	'info_non_suppression_mot_cle' => 'Я НЕ хочу видаляти це ключове слово.',
	'info_notes' => 'Примітки',
	'info_nouvel_article' => 'Новая стаття',
	'info_nouvelle_traduction' => 'Новий переклад:',
	'info_numero_article' => 'НОМЕР СТАТТІ:',
	'info_obligatoire_02' => '(обов’язково)',
	'info_option_accepter_visiteurs' => 'Увімкнути реєстрацію відвідувачів на сайті',
	'info_option_ne_pas_accepter_visiteurs' => 'Відключити реєстрацію відвідувачів на сайті',
	'info_options_avancees' => 'ДОДАТКОВІ НАЛАШТУВАННЯ',
	'info_ou' => 'або...',
	'info_page_interdite' => 'Заборонена сторінка',
	'info_par_nom' => 'за назвою',
	'info_par_nombre_article' => 'за номерами статтей',
	'info_par_statut' => 'за статусом',
	'info_par_tri' => '’(за @tri@)’',
	'info_passe_trop_court' => 'Пароль надто короткий.',
	'info_passe_trop_court_car_pluriel' => 'Пароль повинен мати мінімум @nb@ символів.',
	'info_passes_identiques' => 'Два паролі не співпадають.',
	'info_plus_cinq_car' => 'понад 5 символів',
	'info_plus_cinq_car_2' => '(Понад 5 символів)',
	'info_plus_trois_car' => '(Понад 3 символи)',
	'info_popularite' => 'популярність: @popularite@; відвідання: @visites@',
	'info_post_scriptum' => 'Постскриптум',
	'info_post_scriptum_2' => 'Постскриптум: ',
	'info_pour' => 'для',
	'info_preview_texte' => 'Налаштування попереднього перегляду. Ви можете подивитися, як виглядають на сайті матеріали зі статусом «представлено». Увімкнути цю можливість для усіх авторів, тільки для адміністраторов або відключити взагалі?',
	'info_procedez_par_etape' => 'Будь ласка, виконуйте покроково',
	'info_procedure_maj_version' => 'необхідно запустити процедуру оновлення поточної бази даних для новоі версії SPIP.',
	'info_proxy_ok' => 'Проксі сервер працює.',
	'info_ps' => 'P.S.',
	'info_publier' => 'опублікувати',
	'info_publies' => 'Ваші статті, опубліковані на сайті:',
	'info_question_accepter_visiteurs' => 'Якщо шаблони вашого сайту дозволяють відвідувачам реєструватися, не входячи в адміністративну частину, будь ласка, включіть наступну опцію:',
	'info_question_inscription_nouveaux_redacteurs' => 'Ви хочете дозволити реєстрацію нових користувачів на сайті? Якщо так, то відвідувачі зможуть реєструватися самостійно, використовуючи стандартну форму. Також у них буде доступ в адміністративну частину сайту і можливість створювати нові матеріали.  <div class="notice">Пароль для доступу буде відправлено користувачу  email’ом автоматично. Якщо ваш хостінг не підтримує відправку листів, то ця опція буде марна.</div>',
	'info_qui_edite' => '@nom_auteur_modif@ працював над цим матеріалом @date_diff@ хвилин назад',
	'info_racine_site' => 'Корінь сайту',
	'info_recharger_page' => 'Будь ласка перезавантажте цю сторінку через декілька хвилин.',
	'info_recherche_auteur_zero' => 'Нічого не знайдено на запит          «@cherche_auteur@».',
	'info_recommencer' => 'Будь ласка, спопробуйте ще раз.',
	'info_redacteur_1' => 'Автор',
	'info_redacteur_2' => 'маючи доступ до адміністративної частини (<i>рекомендував</i>), ',
	'info_redacteurs' => 'Автори',
	'info_redaction_en_cours' => 'РЕДАГУЄТЬСЯ',
	'info_redirection' => 'Перенаправлення',
	'info_redirection_activee' => 'Перенаправлення включено.',
	'info_redirection_boucle' => 'Ви намагаєтеся перенаправити статтю саму на себе.',
	'info_redirection_desactivee' => 'Перенаправлення видалено.',
	'info_refuses' => 'Ваші відхилені статті',
	'info_reglage_ldap' => 'Опції <b>налаштування імпорту LDAP</b>',
	'info_renvoi_article' => 'Відвідувач будет перенаправлений за наступним посиланням',
	'info_reserve_admin' => 'Тільки адміністратори можуть змінити цю адресу.',
	'info_restreindre_rubrique' => 'Надати права управління розділами:',
	'info_resultat_recherche' => 'Результати пошуку:',
	'info_rubriques' => 'Розділи',
	'info_rubriques_02' => 'розділи',
	'info_rubriques_trouvees' => 'Знайдені розділи',
	'info_sans_titre' => 'Без назви',
	'info_selection_chemin_acces' => '<b>Виберіть</b> шлях доступу до каталогу:',
	'info_signatures' => 'підписи',
	'info_site' => 'Сайт',
	'info_site_2' => 'Сайт:',
	'info_site_min' => 'сайт',
	'info_site_reference_2' => 'Сайт, що реферується (Referenced site)',
	'info_site_web' => 'САЙТ:',
	'info_sites' => 'сайти',
	'info_sites_lies_mot' => 'Сайти з цим ключовим словом',
	'info_sites_proxy' => 'Використовувати проксі',
	'info_sites_trouves' => 'знайдені сайти',
	'info_sous_titre' => 'Підзаголовок:',
	'info_statut_administrateur' => 'Адміністратор',
	'info_statut_auteur' => 'Статус автора:',
	'info_statut_auteur_2' => 'Я',
	'info_statut_auteur_a_confirmer' => 'Реєстрація буде підтверджена',
	'info_statut_auteur_autre' => 'Інший статус:',
	'info_statut_redacteur' => 'Автор',
	'info_statut_utilisateurs_1' => 'Усталений (default) статус для імпортованих користувачів',
	'info_statut_utilisateurs_2' => 'Виберіть статус, що буде використовуватися для людей з каталогу LDAP, коли вони підключаться вперше. Пізніше ви зможете змінити це значення для кожного автора індивідуально.',
	'info_suivi_activite' => 'Відстежування роботи редакторів',
	'info_surtitre' => 'Топ-заголовок:',
	'info_syndication_integrale_1' => 'Ваш сайт пропонує об’єднані файли (див. «<a href="@url@">@titre@</a>»).',
	'info_syndication_integrale_2' => 'Відправити статтю повністю чи тільки перші абзаци?',
	'info_table_prefix' => 'Ви можете задати свій префікс для імен таблиць бази даних (завдяки цьому ви можете встановити декілька сайтів на одну базу даних). Для написання префіксу використовуйте лише маленькі латинські букви і цифри.',
	'info_taille_maximale_images' => 'Максимальний розмір картинок, з якими може працювати SPIP (у мільйонах пікселів).<br />SPIP не зможет стискати картинки більшого розміру.',
	'info_taille_maximale_vignette' => 'Максимальний розмір зображень, створенних системою:',
	'info_terminer_installation' => 'Теперь ви можете закінчити стандартний процес встановлення.',
	'info_texte' => 'Текст',
	'info_texte_explicatif' => 'Пояснювальний текст',
	'info_texte_long' => '(Довгий текст: він з’явиться в декількох частинах, які будуть повторно зібрані після затвердження.)',
	'info_texte_message' => 'Текст повідомлення:',
	'info_texte_message_02' => 'Текст повідомлення',
	'info_titre' => 'Заголовок:',
	'info_total' => 'всього:',
	'info_tous_articles_en_redaction' => 'Усі статті, що редагуються',
	'info_tous_articles_presents' => 'Усі статті в розділі',
	'info_tous_articles_refuses' => 'Усі відхилені статті',
	'info_tous_les' => 'кожен:',
	'info_tout_site' => 'Весь сайт',
	'info_tout_site2' => 'Статтю не було перекладено на цю мову.',
	'info_tout_site3' => 'Статтю було перекладено на цю мову, але з того часу в оригінал внесено зміни. Необхідно поновити переклад.',
	'info_tout_site4' => 'Статтю було перекладено на цю мову, і переклад актуальний.',
	'info_tout_site5' => 'Вихідна стаття.',
	'info_tout_site6' => '<b>Попередження:</b> відображаються лише вихідні статті. Переклади, пов’язані з оригіналом, - в кольорі, що вказує їхній статус:',
	'info_traductions' => 'Переклади',
	'info_travail_colaboratif' => 'Сумісна робота над статтями',
	'info_un_article' => 'стаття,',
	'info_un_site' => 'сайт,',
	'info_une_rubrique' => 'розділ,',
	'info_une_rubrique_02' => '1 розділ',
	'info_url' => 'Адреса:',
	'info_url_proxy' => 'URL проксі',
	'info_url_proxy_pas_conforme' => 'Невірний URL проксі серверу.',
	'info_url_site_pas_conforme' => 'URL сайту не є валідним.',
	'info_url_test_proxy' => 'URL для перевірки',
	'info_urlref' => 'Гиперпосилання:',
	'info_utilisation_spip' => 'SPIP готовий до роботи',
	'info_visites_par_mois' => 'Щомісячний показ:',
	'info_visiteur_1' => 'Відвідувач',
	'info_visiteur_2' => 'з основної частини сайту',
	'info_visiteurs' => 'Відвідувачі',
	'info_visiteurs_02' => 'Відвідувачі основної частини сайту',
	'info_webmestre_forces' => 'Список вебмастерів міститься в <tt>@file_options@</tt>.',
	'install_adresse_base_hebergeur' => 'Адресу серверу бази даних ви можете дізнатися у свого хостера',
	'install_connect_ok' => 'Була оголошена нова база на сервері @connect@.',
	'install_echec_annonce' => 'Ця інсталяция, напевне, не буде працювати або приведе до нестійкої роботи сайту...',
	'install_extension_mbstring' => 'SPIP не пращює з:',
	'install_extension_php_obligatoire' => 'SPIP вимагає php розширень:',
	'install_login_base_hebergeur' => 'Логін визначається постачальником послуг',
	'install_nom_base_hebergeur' => 'Ім’я бази даних визначається постачальником послуг:',
	'install_pas_table' => 'В базе даних ще нема таблиць',
	'install_pass_base_hebergeur' => 'Ви можете встановити пароль через контрольну панель хостінгу або запитати його в службі підтримки вашого хостінгу.',
	'install_php_version' => 'Версія PHP @version@ надто стара (мінімум = @minimum@)',
	'install_select_langue' => 'Виберіть мову, потім натисніть кнопку «далі», щоб начати процедуру встановлення.',
	'install_select_type_db' => 'Вкажіть тип бази даних:',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Сервер бази даних визначається постачальником послуг',
	'install_table_prefix_hebergeur' => 'Префікс таблиці бази даних:',
	'install_tables_base' => 'Таблиці баз даних',
	'install_types_db_connus' => 'SPIP працює з <b>MySQL</b> і <b>SQLite</b>.',
	'install_types_db_connus_avertissement' => 'Підтримка PostgreSQL поки на експеріментальному рівні. ',
	'instituer_erreur_statut_a_change' => 'Статус вже був змінений',
	'instituer_erreur_statut_non_autorise' => 'Ви не можете вибрати цей статус',
	'intem_redacteur' => 'редактор',
	'intitule_licence' => 'Дозвіл',
	'item_accepter_inscriptions' => 'Дозволити реєстрацію',
	'item_activer_messages_avertissement' => 'Попереджати про сумісну роботу',
	'item_administrateur_2' => 'адміністратор',
	'item_afficher_calendrier' => 'показувати в календарі',
	'item_autoriser_syndication_integrale' => 'Включати цілі статті в об’єднані файли ',
	'item_choix_administrateurs' => 'адміністратори',
	'item_choix_generation_miniature' => 'Створювати зменшені копії автоматично.',
	'item_choix_non_generation_miniature' => 'Не створювати зменшені копії.',
	'item_choix_redacteurs' => 'редактори',
	'item_choix_visiteurs' => 'відвідувачі сайту',
	'item_creer_fichiers_authent' => 'Створити .htpasswd файли',
	'item_login' => 'Логін',
	'item_messagerie_agenda' => 'Увімкнути систему обміну повідомленнями і календар',
	'item_mots_cles_association_articles' => 'статті',
	'item_mots_cles_association_rubriques' => 'розділи',
	'item_mots_cles_association_sites' => 'зробити посилання або об’єднати сайти.',
	'item_non' => 'Ні',
	'item_non_accepter_inscriptions' => 'Не дозволяти реєстрацію',
	'item_non_activer_messages_avertissement' => 'НЕ попереджати про сумісну роботу',
	'item_non_afficher_calendrier' => 'Не показувати календар',
	'item_non_autoriser_syndication_integrale' => 'Відправляти лише короткий виклад',
	'item_non_creer_fichiers_authent' => 'Не створювати ці файли',
	'item_non_messagerie_agenda' => 'Відключити систему обміну повідомленнями і календар',
	'item_non_publier_articles' => 'Публікувати статті тільки після вказаної дати публікації.',
	'item_nouvel_auteur' => 'Новий автор',
	'item_nouvelle_rubrique' => 'Новий розділ',
	'item_oui' => 'Так',
	'item_publier_articles' => 'Негайно публіковати статті, не дивлячись на дату публікації',
	'item_reponse_article' => 'Відповісти на статтю',
	'item_visiteur' => 'відвідувач',

	// J
	'jour_non_connu_nc' => 'невідомий',

	// L
	'label_bando_outils' => 'Панель інструментів',
	'label_bando_outils_afficher' => 'Показати інструменти',
	'label_bando_outils_masquer' => 'Сховати інструменти',
	'label_choix_langue' => 'Мова інтерфейсу',
	'label_nom_fichier_connect' => 'Відображати ім’я серверу',
	'label_slogan_site' => 'Слоган сайту',
	'label_taille_ecran' => 'Ширина робочої області',
	'label_texte_et_icones_navigation' => 'Головне меню',
	'label_texte_et_icones_page' => 'Відоображення сторінки',
	'ldap_correspondance' => 'наслідувати поле @champ@',
	'ldap_correspondance_1' => 'Наслідувати поля LDAP',
	'ldap_correspondance_2' => 'Вкажіть відповідне LDAP поле для кожного з даних полей. Залиште їх порожніми, якщо ви не хочете, щоб вони заповнювались. Декілька LDAP полей розділяються пробілом або комою.',
	'lien_ajouter_auteur' => 'Додати автора',
	'lien_ajouter_une_rubrique' => 'Додати розділ',
	'lien_email' => 'Електронна пошта',
	'lien_nom_site' => 'НАЗВА САЙТУ:',
	'lien_rapide_contenu' => 'Перейти до змісту',
	'lien_rapide_navigation' => 'Перейти до навігації',
	'lien_rapide_recherche' => 'Перейти до пошуку',
	'lien_retirer_auteur' => 'Видалити автора',
	'lien_retirer_rubrique' => 'Видалити розділ',
	'lien_retirer_tous_auteurs' => 'Видалити усіх авторів',
	'lien_retirer_toutes_rubriques' => 'Видалити всі розділи',
	'lien_site' => 'сайт',
	'lien_tout_decocher' => 'Зніміть',
	'lien_tout_deplier' => 'Развернуть усі ',
	'lien_tout_replier' => 'Згорнути усе',
	'lien_tout_supprimer' => 'Видалити усе',
	'lien_trier_nom' => 'Сортирувати за ім´ям',
	'lien_trier_nombre_articles' => 'Сортирувати за номерами статтей',
	'lien_trier_statut' => 'Сортирувати за статусом',
	'lien_voir_en_ligne' => 'ПЕРЕГЛЯД ОНЛАЙН:',
	'logo_article' => 'ЛОГОТИП СТАТТІ',
	'logo_auteur' => 'ЛОГОТИП АВТОРА',
	'logo_rubrique' => 'ЛОГОТИП РОЗДІЛУ',
	'logo_site' => 'ЛОГОТИП САЙТУ',
	'logo_standard_rubrique' => 'Стандартний логотип розділу',
	'logo_survol' => 'При наведенні миші',

	// M
	'menu_aide_installation_choix_base' => 'Виберіть вашу базу даних',
	'module_fichier_langue' => 'Мовний файл',
	'module_raccourci' => 'Ярлик',
	'module_texte_affiche' => 'Показаний текст',
	'module_texte_explicatif' => 'Ви можете вставити наступні ярлики в шаблон вашого сайту. Їх будє автоматично перекладено на різні мови, для яких існує мовний файл.',
	'module_texte_traduction' => 'Мовний файл «@module@» є доступним в:',
	'mois_non_connu' => 'невідомий',

	// N
	'nouvelle_version_spip' => 'Доступне оновлення версії SPIP @version@ ',
	'nouvelle_version_spip_majeure' => 'Доступна нова версія SPIP @version@ ',

	// O
	'onglet_contenu' => 'Зміст',
	'onglet_declarer_une_autre_base' => 'Об´явити іншу базу даних',
	'onglet_discuter' => 'Обговорити',
	'onglet_interactivite' => 'Інтерактивність',
	'onglet_proprietes' => 'Властивості',
	'onglet_repartition_actuelle' => 'зараз',
	'onglet_sous_rubriques' => 'Підрубрики',

	// P
	'page_pas_proxy' => 'Ця сторінка не повинна проходити через проксі',
	'pas_de_proxy_pour' => 'Якщо необхідно, вкажіть для яких комп’ютерів або доменів не треба застосовувати проксі (наприклад: @exemple@) ',
	'phpinfo' => 'Конфігурація PHP',
	'plugin_charge_paquet' => 'Завантаження архиву файлу @name@',
	'plugin_charger' => 'Завантажити',
	'plugin_erreur_charger' => 'Помилка: неможливо завантажити @zip@',
	'plugin_erreur_droit1' => 'Нема прав для запису в папку  <code>@dest@</code>.',
	'plugin_erreur_droit2' => 'Будь ласка, перевірте права на запис для цієї папки (і за необхідності створіть її). Або перепишіть файли по FTP.',
	'plugin_erreur_zip' => 'pclzip збій: помилка @status@',
	'plugin_etat_developpement' => 'у розробці',
	'plugin_etat_experimental' => 'експериментальний',
	'plugin_etat_stable' => 'стабільний',
	'plugin_etat_test' => 'тестується',
	'plugin_impossible_activer' => 'Неможливо увімкнути плагін @plugin@',
	'plugin_info_automatique1' => 'щоб дозволити автоматичну установку плагінів:',
	'plugin_info_automatique1_lib' => 'Якщо ви хочете дозволити автоматичну установку цієї бібліотеки, то:',
	'plugin_info_automatique2' => 'Створіть папку <code>@rep@</code> ;',
	'plugin_info_automatique3' => 'Встановіть права доступу до каталогу (755 або 777).',
	'plugin_info_automatique_creer' => 'для створення в корені вебсайту.',
	'plugin_info_automatique_exemples' => 'Офіціальні RSS аркуші з плагінами:',
	'plugin_info_automatique_ftp' => 'Ви можете встановити плагіни по FTP в каталог <tt>@rep@</tt> ',
	'plugin_info_automatique_lib' => 'Деякі плагіни повинні мати можливість завантажувати файли в каталог <code>lib/</code>. Можливо, його необхідно створити самостійно.',
	'plugin_info_automatique_liste' => 'Ваші плагіни:',
	'plugin_info_automatique_liste_officielle' => 'офіційні плагіни',
	'plugin_info_automatique_liste_update' => 'Поновити списки',
	'plugin_info_automatique_ou' => 'або...',
	'plugin_info_automatique_select' => 'виберіть плагін, SPIP завантажить і встановить його в каталог <code>@rep@</code>. Якщо плагін вже встановлений, його буде оновлено.',
	'plugin_info_credit' => 'Авторська інформація',
	'plugin_info_erreur_xml' => 'Неправильна декларація плагіна',
	'plugin_info_install_ok' => 'Встановлення пройшло успішно',
	'plugin_info_necessite' => 'Необхідно:',
	'plugin_info_non_compatible_spip' => 'Плагін несумісний з поточною версією SPIP',
	'plugin_info_plugins_dist_1' => 'Ці плагіни завантажені і встановлені в папці @plugins_dist@.',
	'plugin_info_plugins_dist_2' => 'Їх не можна відключити.',
	'plugin_info_telecharger' => 'завантажити с @url@ і встановити в @rep@',
	'plugin_info_upgrade_ok' => 'Обновлення пройшло успішно',
	'plugin_librairies_installees' => 'Встановлені бібліотеки',
	'plugin_necessite_extension_php' => 'Необхідно PHP-розширення @plugin@ версії @version@.',
	'plugin_necessite_extension_php_sans_version' => 'Необхідно PHP-розширення @plugin@',
	'plugin_necessite_lib' => 'Для цього плагіна необхідна бібліотека  @lib@',
	'plugin_necessite_php' => 'Необхідно @plugin@ версії @version@.',
	'plugin_necessite_plugin' => 'Для цього плагіна необхідний @plugin@  @version@ або новіший.',
	'plugin_necessite_plugin_sans_version' => 'Потрібний плагін @plugin@',
	'plugin_necessite_spip' => 'Для цього плагіна потрібний SPIP @version@ або новіший.',
	'plugin_source' => 'джерело: ',
	'plugin_titre_automatique' => 'Автоматичне встановлення',
	'plugin_titre_automatique_ajouter' => 'Додати плагін',
	'plugin_titre_installation' => 'Встановити плагін @plugin@ ',
	'plugin_titre_modifier' => 'Мої плагіни',
	'plugin_utilise_extension_php' => 'Використовується PHP-розширення @plugin@ версії @version@.',
	'plugin_utilise_php' => 'Використовується @plugin@ версії @version@.',
	'plugin_utilise_plugin' => 'Використовуйте плагін @plugin@ en версії @version@.',
	'plugin_zip_active' => 'Продовжити для активації',
	'plugin_zip_adresse' => 'Вкажіть посилання на zip файла плагіна для завантаження або адресу RSS листа плагінів.',
	'plugin_zip_adresse_champ' => 'URL плагіна (zip file) або RSS листа',
	'plugin_zip_content' => 'Він містить наступні файли(@taille@),<br />готові до встановлення в каталозі <code>@rep@</code>',
	'plugin_zip_installe_finie' => 'Файл @zip@ распакований і встановлений.',
	'plugin_zip_installe_rep_finie' => 'Файл @zip@ распакований і встановлений в каталозі @rep@ ',
	'plugin_zip_installer' => 'Теперь ви можете встановити.',
	'plugin_zip_telecharge' => 'Файл @zip@ було завантажено',
	'plugins_actif_aucun' => 'Нема вимкенених плагінів.',
	'plugins_actif_un' => 'Включений один плагін',
	'plugins_actifs' => '@count@ плагінів включено.',
	'plugins_actifs_liste' => 'Включені ',
	'plugins_compte' => '@count@ плагіни',
	'plugins_disponible_un' => 'Доступний один плагін',
	'plugins_disponibles' => 'доступно @count@ плагінів.',
	'plugins_erreur' => 'Помилка в плагінах: @plugins@',
	'plugins_liste' => 'Встановлені плагіни',
	'plugins_liste_dist' => 'Захищені плагіни',
	'plugins_recents' => 'останні плагіни',
	'plugins_tous_liste' => 'Усі',
	'plugins_vue_hierarchie' => 'Ієрархія',
	'plugins_vue_liste' => 'Список',
	'protocole_ldap' => 'Версія протоколу:',

	// Q
	'queue_executer_maintenant' => 'Запустити',
	'queue_info_purger' => 'Ви можете видалити усі поточні завдання і очистити всю чергу завдань',
	'queue_nb_jobs_in_queue' => 'В черзі @nb@ завдань',
	'queue_next_job_in_nb_sec' => 'Наступне завдання через @nb@ s',
	'queue_no_job_in_queue' => 'Список завдань пустий',
	'queue_one_job_in_queue' => '1 завдання в черзі',
	'queue_priorite_tache' => 'пріорітет',
	'queue_purger_queue' => 'Очистити список завдань',
	'queue_titre' => 'Список завдань',

	// R
	'repertoire_plugins' => 'Репозиторій:',
	'required' => '(обов’язково)',

	// S
	'sans_heure' => 'час невизначений',
	'statut_admin_restreint' => '(обмежений адміністратор)',
	'statut_webmestre' => 'веб-майстер',

	// T
	'tache_cron_asap' => 'Завдання CRON @function@ (ASAP)',
	'tache_cron_secondes' => 'Завдання CRON @function@ (кожні @nb@ с)',
	'taille_cache_image' => 'Кеш файлів зображень (автоматично стиснені картинки, зображення формул в форматі TeX і текст, трасформований в графіку) займає @taille@ в каталозі @dir@.',
	'taille_cache_infinie' => 'На вашому сайті нема обмежень на розмір кеша.',
	'taille_cache_maxi' => 'Заданий максимальний розмір файлів кеша складає приблизно <b> @octets@ </b>.',
	'taille_cache_moins_de' => 'Розмір кеша менше @octets@.',
	'taille_cache_octets' => 'Приблизний розмір кеша @octets@.',
	'taille_cache_vide' => 'Кеш очищено.',
	'taille_repertoire_cache' => 'Поточний розмір кеша',
	'text_article_propose_publication' => 'Статтю представлено до публікації.',
	'texte_acces_ldap_anonyme_1' => 'Деякі сервери LDAP не дозволяють анонімного доступу. В цьому випадку ви повинні вказати вихідний ідентифікатор доступу, щоб згодом мати можливість шукати інформацію в каталозі. Але в більшості випадків наступні поля можна залишити порожніми.',
	'texte_admin_effacer_01' => 'Ця команда видаляє <i>увесь</i> вміст бази даних, включаючи <i>усі</i> параметри доступу для редакторів і адміністраторів. Після її виконання ви повинні перевстановити SPIP, щоб відновити нову базу даних і доступ першого адміністратора.',
	'texte_adresse_annuaire_1' => '(Якщо ваш каталог установлено на тому ж самому комп’ютері, що і ваш вебсайт, це, напевно, - «localhost».)',
	'texte_ajout_auteur' => 'Наступний автор був доданий до статті:',
	'texte_annuaire_ldap_1' => 'Якщо ви маєте доступ до каталогу(LDAP), то можете використовувати його для автоматичного імпорту користувачів SPIP.',
	'texte_article_statut' => 'Статус статті:',
	'texte_article_virtuel' => 'Віртуальна стаття',
	'texte_article_virtuel_reference' => '<b>Віртуальна стаття:</b> стаття, на яку є посилання на вашому SPIP сайті, але яка насправді знаходиться на іншому URL. Щоб видалити перенаправлення, видаліть адресу, яку наведено вище.',
	'texte_aucun_resultat_auteur' => 'Нема результатів для «@cherche_auteur@».',
	'texte_auteur_messagerie' => 'Цей сайт може постійнно контролювати список редакторів, які знаходяться он-лайн, що дозволяє вам обмінюватися повідомленнями в реальному часі. Ви можете вирішити не з’являтися в цьому списку (тоді вас «не побачать» інші користувачі).',
	'texte_auteurs' => 'АВТОРИ',
	'texte_choix_base_1' => 'Вибрати вашу базу даних:',
	'texte_choix_base_2' => 'SQL сервер містить декілька баз даних.',
	'texte_choix_base_3' => '<b>Виберіть</b> нижче ту, яку ваш інтернет провайдер може віднести до вас:',
	'texte_choix_table_prefix' => 'Префікс для таблиць БД:',
	'texte_compte_element' => '@count@ елемент',
	'texte_compte_elements' => '@count@ елементи',
	'texte_conflit_edition_correction' => 'Будь ласка, перевірте нижче різницю між двома версіями. Таким чином ви можете зкопіювати ваші зміни і почати спочатку.',
	'texte_connexion_mysql' => 'Параметри доступу до бази даних задаются в контрольній панелі хостінга. Якщо у вас нема можливості управляти вашими базами даних, ви можете запитати про допомогу в службі підтримки хостінгу.',
	'texte_contenu_article' => '(Короткий зміст статті.)',
	'texte_contenu_articles' => 'Вибрати додаткові інформаційні поля для статтей. В залежності від того, як запрограмовано ваш сайт, вони можуть відображатися або не відображатися в загальному доступі. ',
	'texte_crash_base' => 'Якщо ваша база даних пошкоджена, ви можете спробувати відновити її автоматично.',
	'texte_creer_rubrique' => 'Створіть хоча б одну рубрику, <br />щоб писати статті.',
	'texte_date_creation_article' => 'ДАТА створення статті:',
	'texte_date_creation_objet' => 'Дата створення:', # on ajoute le ":"
	'texte_date_publication_anterieure' => 'Додаткова дата:',
	'texte_date_publication_anterieure_nonaffichee' => 'Приховати дату більш ранньої публікації.',
	'texte_date_publication_article' => 'ДАТА ОНЛАЙН ПУБЛИКАЦІИ:',
	'texte_date_publication_objet' => 'Дата публікації:',
	'texte_definir_comme_traduction_rubrique' => 'Ця рубрика є перекладом рубрики за номером:',
	'texte_descriptif_rapide' => 'Короткий опис',
	'texte_effacer_base' => 'Видалити базу даних SPIP',
	'texte_effacer_statistiques' => 'Видалити статистику',
	'texte_en_cours_validation' => 'Матеріали, що потребують перевірки. ',
	'texte_enrichir_mise_a_jour' => 'Ви можете покращити свій текст, користуючись «типографськими скороченнями»',
	'texte_fichier_authent' => '<b>Чи повинен SPIP створювати <tt>.htpasswd</tt> і <tt>.htpasswd-admin</tt> файли у папці @dossier@?</b> <p>Ці файли використовуються для обмеження доступу авторів і адміністраторов до інших частин сайту (наприклад, до папки з серверною статистикою).</p> <p>Якщо у вас нема необхідності в таких діях, то залиште це значення як усталено (default).</p>',
	'texte_informations_personnelles_1' => 'Теперь система створить ваш обліковий запис на сайті.',
	'texte_informations_personnelles_2' => '(Примітка: Якщо ви перевстановлюєте SPIP і ваш старий логін і пароль як і раніше працюють, ви можете',
	'texte_introductif_article' => '(Вступний текст до статті)',
	'texte_jeu_caractere' => 'Рекомендуємо використовувати кодування (<tt>utf-8</tt>) на вашому сайті. Це дасть можливість відображати текст будь-якою мовою. ',
	'texte_jeu_caractere_3' => 'Поточне кодування:',
	'texte_jeu_caractere_4' => 'Якщо це не відповідає ситуації з вашими даними (наприклад, після відновлення бази даних з резервної копії), або якщо <em>ви створюєте цей сайт</em> і хочете використовувати різні набори символів, будь ласка, вкажіть набор символів тут:',
	'texte_login_ldap_1' => '(Залиште порожнім для анонімного доступу або введіть повний шлях, наприклад «<tt>uid=smith, ou=users, dc=my-domain, dc=com </tt>».)',
	'texte_login_precaution' => 'Увага! Це ваш поточний логін на сайті, міняйте вдумливо.',
	'texte_messagerie_agenda' => 'Система відправлення повідомлень дозволяє авторам сайту спілкуватися безпосередньо в редакційній частині сайту. Вона пов’язана з календарем.',
	'texte_mise_a_niveau_base_1' => 'Ви тільки но поновили файли SPIP. Теперь ви повинні поновити базу даних сайту.',
	'texte_modifier_article' => 'Змінити статтю:',
	'texte_multilinguisme' => 'Якщо на сайті будуть розміщуватися матеріали деякільками мовами, ви можете додати «меню вибору мови» для цих матеріалів.',
	'texte_multilinguisme_trad' => 'Також ви можете дозволити об’єднувати різні переклади одного і того ж матеріалу. ',
	'texte_non_compresse' => '<i>розпакувати</i> (ваш сервер не підтримує цю функцію)',
	'texte_nouvelle_version_spip_1' => 'Ви встановили нову версію SPIP.',
	'texte_nouvelle_version_spip_2' => 'Щоб поновити сайт до нової версії, якщо ви вебмастер цього сайту, будь ласка, видаліть файл @connect@ і повторно почніть установку, щоб поновити налаштування підключення до бази даних. <p>(PS: Якщо ви забули свої параметри з’єднання, то вони зберігаються в файлі @connect@ </p>',
	'texte_operation_echec' => 'Поверніться до попередньої сторінки, виберіть іншу базу даних або створіть нову. Перевірте інформацію, надану вашим хостом.',
	'texte_plus_trois_car' => 'понад 3 символи',
	'texte_plusieurs_articles' => 'Декілька авторів було знайдено для «@cherche_auteur@»:',
	'texte_port_annuaire' => '(Усталене (default) значення є підходящим.)',
	'texte_presente_plugin' => 'На цій сторінці перелік плагінів, доступних на вашому сайті. Включіть плагін, відзначивши відповідний квадратик.',
	'texte_proposer_publication' => 'Коли ви закінчите роботу над статтею, <br />ви можете представити її до публікації.',
	'texte_proxy' => 'В деяких випадках (внутрішні або захищені мережі...) необхідно використовувати <i>proxy HTTP</i>, щоб дістатися віддалених сайтів (SPIP документація, сайти, що реферуються і т.д.). В такому разі введіть його адресу нижче в форму <tt><html> http://proxy:8080 </html></tt> (@proxy_en_cours@). В більшості випадків ви можете залишити це поле порожнім.',
	'texte_publication_articles_post_dates' => 'Коли публікувати статті з датою публікації в майбутньому?',
	'texte_rappel_selection_champs' => '[Не забудьте правильно обрати поле.]',
	'texte_recalcul_page' => 'Якщо ви хочете поновити тільки одну сторінку, то можете зробити це в основній частині, використовуючи кнопку «Поновити сторінку».',
	'texte_recuperer_base' => 'Відновити базу даних',
	'texte_reference_mais_redirige' => 'посилання на статтю вашого SPIP сайту, але переадресоване на іншу адресу.',
	'texte_requetes_echouent' => '<b>Якщо при виконанні SQL запитів часто з’являються повідомлення про помилки, цілком можливо, що пошкоджено саму базу даних.</b> <p>В SQL вбудовано функцію ремонту і відновлення пошкоджених таблиць. Ви можете спробувати виконати процедуру відновлення або ремонту зараз.</p>',
	'texte_selection_langue_principale' => 'Ви можете вибрати «головну мову» сайту. Вона задає: 
<ul>
<li>усталений формат виведення дати</li> 
<li>усталену мову для використання на сайті</li> 
<li>усталену мову для адміністративной частини.</li>
</ul>',
	'texte_sous_titre' => 'Підзаголовок',
	'texte_statistiques_visites' => '(темні штрихи: неділя / темна крива: середній рівень)',
	'texte_statut_attente_validation' => 'очікує затвердження',
	'texte_statut_publies' => 'опубліковані на сайті',
	'texte_statut_refuses' => 'відхилено',
	'texte_suppression_fichiers' => 'використовуйте команду для видалення усіх файлів з кеша SPIP. Це дозволить поновити усі сторінки сайту. Це дуже зручно, якщо ви змінили шаблони або поновили значну кількість інформації на сайті.',
	'texte_sur_titre' => 'Топ-заголовок',
	'texte_table_ok' => ':  таблиця ОК.',
	'texte_tentative_recuperation' => 'Спроба відновлення ',
	'texte_tenter_reparation' => 'Спроба відновлення бази даних',
	'texte_test_proxy' => 'Щоб спробувати проксі, введіть тут адрес вебсайта, який ви хочете перевірити.',
	'texte_titre_02' => 'Заголовок:',
	'texte_titre_obligatoire' => '<b>Заголовок</b> [обов’язково]',
	'texte_travail_article' => '@nom_auteur_modif@ роботав над цією статтею @date_diff@ хвилин тому',
	'texte_travail_collaboratif' => 'Якщо декілька авторів редагують одну і ту ж саму статтю, то система позначає її як «в роботі» і обмежує доступ до неї, щоб уникнути втрат інформації внаслідок одночасного редагування матеріалу. Зазвичай цю можливість відключено.',
	'texte_vide' => 'очистити',
	'texte_vider_cache' => 'Очистити кеш',
	'titre_admin_tech' => 'Технічне обслуговування',
	'titre_admin_vider' => 'Технічне обслуговування',
	'titre_ajouter_un_auteur' => 'Додати автора',
	'titre_ajouter_un_mot' => 'Додати ключове слово',
	'titre_cadre_afficher_article' => 'Показати статті:',
	'titre_cadre_afficher_traductions' => 'Показати стан перекладу для наступних мов:',
	'titre_cadre_ajouter_auteur' => 'ДОДАТИ АВТОРА:',
	'titre_cadre_interieur_rubrique' => 'В розділі',
	'titre_cadre_numero_auteur' => 'НОМЕР АВТОРА',
	'titre_cadre_numero_objet' => '@objet@ НОМЕР:',
	'titre_cadre_signature_obligatoire' => '<b>Підпис</b> [обов’язково]<br />',
	'titre_config_contenu_notifications' => 'Повідомлення',
	'titre_config_contenu_prive' => 'У редакційній частині',
	'titre_config_contenu_public' => 'В публічній частині',
	'titre_config_fonctions' => 'Налаштування сайту',
	'titre_config_langage' => 'Вибір мови інтерфейсу',
	'titre_configuration' => 'Налаштування сайту',
	'titre_configurer_preferences' => 'Змінити налаштування',
	'titre_configurer_preferences_menus' => 'Налаштування меню',
	'titre_conflit_edition' => 'Протиріччя в процесі зміни',
	'titre_connexion_ldap' => 'Опції: <b>ваше LDAP з’єднання</b>',
	'titre_groupe_mots' => 'ГРУППА КЛЮЧОВИХ СЛІВ:',
	'titre_identite_site' => 'Інформація про сайт',
	'titre_langue_article' => 'Мова статті',
	'titre_langue_rubrique' => 'МОВА РОЗДІЛУ',
	'titre_langue_trad_article' => 'МОВА та ПЕРЕКЛАДИ СТАТТІ',
	'titre_les_articles' => 'СТАТТІ',
	'titre_messagerie_agenda' => 'Система обміну повідомленнями і календар',
	'titre_naviguer_dans_le_site' => 'Перегляд сайту...',
	'titre_nouvelle_rubrique' => 'Новий розділ',
	'titre_numero_rubrique' => 'НОМЕР РОЗДІЛУ:',
	'titre_page_articles_edit' => 'Змінити: @titre@',
	'titre_page_articles_page' => 'Статті',
	'titre_page_articles_tous' => 'Весь сайт',
	'titre_page_calendrier' => 'Календар @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Налаштування сайту',
	'titre_page_delete_all' => 'повне і незворотне видалення ',
	'titre_page_recherche' => 'Результати пошуку @recherche@',
	'titre_page_statistiques_referers' => 'Статистика (вхідні посилання)',
	'titre_page_upgrade' => 'SPIP оновлення',
	'titre_preference_menus_favoris' => 'Обране меню',
	'titre_publication_articles_post_dates' => 'Відкладена публікація статтей',
	'titre_reparation' => 'Відновити',
	'titre_suivi_petition' => 'Відстеження звернень (петицій)',
	'tls_ldap' => 'Transport Layer Security :',
	'trad_article_traduction' => 'Усі версії цієї статті:',
	'trad_delier' => 'Видалити зв’язок з цим перекладом',
	'trad_lier' => 'Ця стаття є перекладом статті за номером:',
	'trad_new' => 'Додати новий переклад',

	// U
	'utf8_convert_erreur_orig' => 'Помилка: набір символів @charset@ не підтримується.',

	// V
	'version' => 'Версія:'
);
